.. Automatically generated from LONG_DESCRIPTION keyword in 
.. setup.py. Do not edit directly.

contactpp
=========

contactpp is a package for the generation of pseudopotentials for the 
contact interaction. The theory is outlined in [BLNC]_. 


.. [BLNC] P.O. Bugnion, P. López Ríos, R.J. Needs, and G.J. Conduit, 
         High-fidelity pseudopotentials for the contact interaction.

Links
-----

* Home page: https://pypi.python.org/pypi/contactpp
* Documentation: http://contactpp.readthedocs.org/en/latest/
* Source code: https://github.com/pbugnion/contactpp
* Issues: https://github.com/pbugnion/contactpp/issues


Installation
------------

contactpp requires python2.7, numpy and scipy. On Ubuntu, for instance,
these can be installed with:

    $ sudo apt-get install python-numpy python-scipy

The easiest way to download and install ``contactpp`` is from the Python
package index. Run::

    $ easy_install contactpp

This requires root access (unless you are running in a virtual environment).
To install without root access, run::

    $ easy_install --user contactpp

To install from github, clone the git repository using::

    $ git clone https://github.com/pbugnion/contactpp.git

Navigate to the source's root directory (``contactpp``) and run::

    $ python setup.py install

If you have a zip or a tar.gz archive of the source, unpack the compressed archive into a directory, navigate to this directory and run::

    $ python setup.py install

You may need to run this as root, unless you are running in a virtual environment.



Issue reporting and contributing
--------------------------------

Report issues using the `github issue tracker <https://github.com/pbugnion/contactpp/issues>`_.

Read the CONTRIBUTING guide to learn how to contribute.
